==> opennms-model-1.8.17-20120120.162530-45-sources.jar: org/opennms/netmgt/model/OnmsMapList.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.netmgt.model;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.LinkedList;
import java.util.Collection;
import java.util.List;

/**
 * <p>OnmsMapList class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
@XmlRootElement(name = "maps")
public class OnmsMapList extends LinkedList<OnmsMap> {
    private static final long serialVersionUID = -6071472722900233605L;


    /**
     * <p>Constructor for OnmsMapList.</p>
     */
    public OnmsMapList() {
        super();
    }

    /**
     * <p>Constructor for OnmsMapList.</p>
     *
     * @param c a {@link java.util.Collection} object.
     */
    public OnmsMapList(Collection<? extends OnmsMap> c) {
        super(c);
    }

    /**
     * <p>getMaps</p>
     *
     * @return a {@link java.util.List} object.
     */
    @XmlElement(name = "map")
    public List<OnmsMap> getMaps() {
        return this;
    }

    /**
     * <p>setMaps</p>
     *
     * @param maps a {@link java.util.List} object.
     */
    public void setMaps(List<OnmsMap> maps) {
        clear();
        addAll(maps);
    }

}

==> opennms-model-1.9.8-sources.jar: org/opennms/netmgt/model/OnmsMapList.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.netmgt.model;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.LinkedList;
import java.util.Collection;
import java.util.List;

/**
 * <p>OnmsMapList class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
@XmlRootElement(name = "maps")
public class OnmsMapList extends LinkedList<OnmsMap> {
    private static final long serialVersionUID = -6071472722900233605L;


    /**
     * <p>Constructor for OnmsMapList.</p>
     */
    public OnmsMapList() {
        super();
    }

    /**
     * <p>Constructor for OnmsMapList.</p>
     *
     * @param c a {@link java.util.Collection} object.
     */
    public OnmsMapList(Collection<? extends OnmsMap> c) {
        super(c);
    }

    /**
     * <p>getMaps</p>
     *
     * @return a {@link java.util.List} object.
     */
    @XmlElement(name = "map")
    public List<OnmsMap> getMaps() {
        return this;
    }

    /**
     * <p>setMaps</p>
     *
     * @param maps a {@link java.util.List} object.
     */
    public void setMaps(List<OnmsMap> maps) {
        clear();
        addAll(maps);
    }

    /**
     * <p>getCount</p>
     *
     * @return a {@link java.lang.Integer} object.
     */
    @XmlAttribute(name="count")
    public Integer getCount() {
        return this.size();
    }

}
